# DLCU
This repositroy contains material from the [DeepLabCut-Utils](https://github.com/DeepLabCut/DLCutils) repository by [DeepLabCut](https://github.com/DeepLabCut) in a python package.

![PyPI](https://img.shields.io/pypi/v/dlcu) [![PEP8](https://img.shields.io/badge/code%20style-pep8-green.svg)](https://www.python.org/dev/peps/pep-0008/)

## Package Installation
```bash
$ pip install dlcu
```
